import { app, shell, BrowserWindow, ipcMain } from 'electron'
import { join } from 'path'
import { electronApp, optimizer, is } from '@electron-toolkit/utils'
import icon from '../../resources/icon.png?asset'

let mainWindow

const createWindow = () => {
  mainWindow = new BrowserWindow({
    width: 900,
    height: 670,
    show: false,
    autoHideMenuBar: true,
    ...(process.platform === 'linux' ? { icon } : {}),
    webPreferences: {
      preload: join(__dirname, '../preload/index.js'),
      sandbox: false,
      nodeIntegration: false,
      contextIsolation: true
    }
  })

  mainWindow.on('ready-to-show', () => {
    mainWindow.show()
  })

  mainWindow.webContents.setWindowOpenHandler((details) => {
    shell.openExternal(details.url)
    return { action: 'deny' }
  })

  if (is.dev && process.env['ELECTRON_RENDERER_URL']) {
    mainWindow.loadURL(process.env['ELECTRON_RENDERER_URL'])
  } else {
    mainWindow.loadFile(join(__dirname, '../renderer/index.html'))
  }
}

// IPC handlers for input overlay
ipcMain.on('show-input-overlay', (event, data) => {
  if (mainWindow) {
    mainWindow.webContents.send('show-input-overlay', data)
  }
})

ipcMain.on('hide-input-overlay', () => {
  if (mainWindow) {
    mainWindow.webContents.send('hide-input-overlay')
  }
})

ipcMain.on('input-overlay-submit', (event, data) => {
  console.log('Input overlay submit:', data)
  // You can handle the submitted input here
  // For example, send it to other parts of your application
})

// Function to show input overlay (can be called globally)
const showInputOverlay = (options = {}) => {
  if (mainWindow) {
    mainWindow.webContents.send('show-input-overlay', options)
  }
}

// Export for potential use by other modules
global.showInputOverlay = showInputOverlay

app.whenReady().then(() => {
  electronApp.setAppUserModelId('com.electron')

  app.on('browser-window-created', (_, window) => {
    optimizer.watchWindowShortcuts(window)
  })

  createWindow()

  app.on('activate', function () {
    if (BrowserWindow.getAllWindows().length === 0) createWindow()
  })
})

app.on('window-all-closed', () => {
  if (process.platform !== 'darwin') {
    app.quit()
  }
})
